diff --git a/apps/calendar/apps/web/src/lib/components/AppSlider.svelte b/apps/calendar/apps/web/src/lib/components/AppSlider.svelte
index 4242067aa..b36ac8d18 100644
--- a/apps/calendar/apps/web/src/lib/components/AppSlider.svelte
+++ b/apps/calendar/apps/web/src/lib/components/AppSlider.svelte
@@ -1,10 +1,10 @@
-
-
-
- {#if isOpen}
-
- {#each supportedLocales as lang}
-
- {/each}
-
- {/if}
-
+
diff --git a/apps/context/apps/web/src/lib/components/ConfirmDialog.svelte b/apps/context/apps/web/src/lib/components/ConfirmDialog.svelte
deleted file mode 100644
index b8bd9b388..000000000
--- a/apps/context/apps/web/src/lib/components/ConfirmDialog.svelte
+++ /dev/null
@@ -1,48 +0,0 @@
-
-
-{#if open}
-
-
-
-
{title}
-
{message}
-
-
-
-
-
-
-{/if}
diff --git a/apps/context/apps/web/src/routes/(app)/documents/+page.svelte b/apps/context/apps/web/src/routes/(app)/documents/+page.svelte
index 59984f47f..df6de136c 100644
--- a/apps/context/apps/web/src/routes/(app)/documents/+page.svelte
+++ b/apps/context/apps/web/src/routes/(app)/documents/+page.svelte
@@ -11,7 +11,7 @@
getAllDocumentTags,
} from '$lib/data/queries';
import DocumentCard from '$lib/components/DocumentCard.svelte';
- import ConfirmDialog from '$lib/components/ConfirmDialog.svelte';
+ import { ConfirmationModal } from '@manacore/shared-ui';
import type { DocumentType } from '$lib/types';
let deleteTarget = $state(null);
@@ -190,12 +190,11 @@
{/if}
- (deleteTarget = null)}
+ onClose={() => (deleteTarget = null)}
/>
diff --git a/apps/context/apps/web/src/routes/(app)/documents/[id]/+page.svelte b/apps/context/apps/web/src/routes/(app)/documents/[id]/+page.svelte
index 126e08159..3f901a238 100644
--- a/apps/context/apps/web/src/routes/(app)/documents/[id]/+page.svelte
+++ b/apps/context/apps/web/src/routes/(app)/documents/[id]/+page.svelte
@@ -9,7 +9,7 @@
import { tokensStore } from '$lib/stores/tokens.svelte';
import DocumentEditor from '$lib/components/DocumentEditor.svelte';
import AIToolbar from '$lib/components/AIToolbar.svelte';
- import ConfirmDialog from '$lib/components/ConfirmDialog.svelte';
+ import { ConfirmationModal } from '@manacore/shared-ui';
import type { Document, DocumentType } from '$lib/types';
import type { InsertionMode } from '$lib/services/ai';
@@ -164,12 +164,11 @@
{/if}
- (showDeleteConfirm = false)}
+ onClose={() => (showDeleteConfirm = false)}
/>
diff --git a/apps/context/apps/web/src/routes/(app)/spaces/+page.svelte b/apps/context/apps/web/src/routes/(app)/spaces/+page.svelte
index bd187ce13..adf5557a0 100644
--- a/apps/context/apps/web/src/routes/(app)/spaces/+page.svelte
+++ b/apps/context/apps/web/src/routes/(app)/spaces/+page.svelte
@@ -6,7 +6,7 @@
import { useAllSpaces } from '$lib/data/queries';
import SpaceCard from '$lib/components/SpaceCard.svelte';
import CreateSpaceModal from '$lib/components/CreateSpaceModal.svelte';
- import ConfirmDialog from '$lib/components/ConfirmDialog.svelte';
+ import { ConfirmationModal } from '@manacore/shared-ui';
import type { Space } from '$lib/types';
let searchQuery = $state('');
@@ -131,12 +131,11 @@
onClose={() => (showCreateModal = false)}
/>
- (deleteTarget = null)}
+ onClose={() => (deleteTarget = null)}
/>
diff --git a/apps/times/apps/web/src/lib/components/ConfirmDialog.svelte b/apps/times/apps/web/src/lib/components/ConfirmDialog.svelte
deleted file mode 100644
index b806cb27d..000000000
--- a/apps/times/apps/web/src/lib/components/ConfirmDialog.svelte
+++ /dev/null
@@ -1,56 +0,0 @@
-
-
-{#if visible}
-
-
-
{title}
- {#if message}
-
{message}
- {/if}
-
-
-
-
-
-
-{/if}
diff --git a/apps/times/apps/web/src/lib/components/EntryItem.svelte b/apps/times/apps/web/src/lib/components/EntryItem.svelte
index ee83b9fa4..bc35ac7ca 100644
--- a/apps/times/apps/web/src/lib/components/EntryItem.svelte
+++ b/apps/times/apps/web/src/lib/components/EntryItem.svelte
@@ -5,7 +5,7 @@
import { formatDurationCompact } from '$lib/data/queries';
import { CurrencyDollar } from '@manacore/shared-icons';
import type { TimeEntry, Project, Client } from '@times/shared';
- import ConfirmDialog from './ConfirmDialog.svelte';
+ import { ConfirmationModal } from '@manacore/shared-ui';
let {
entry,
@@ -200,10 +200,10 @@
{/if}
- (showDeleteConfirm = false)}
+ onClose={() => (showDeleteConfirm = false)}
/>
diff --git a/apps/times/apps/web/src/routes/(app)/clients/+page.svelte b/apps/times/apps/web/src/routes/(app)/clients/+page.svelte
index 4ff30bf60..5f7c28059 100644
--- a/apps/times/apps/web/src/routes/(app)/clients/+page.svelte
+++ b/apps/times/apps/web/src/routes/(app)/clients/+page.svelte
@@ -5,7 +5,7 @@
import { getTotalDuration, formatDurationCompact } from '$lib/data/queries';
import type { Client, Project, TimeEntry } from '@times/shared';
import { PROJECT_COLORS } from '@times/shared/constants';
- import ConfirmDialog from '$lib/components/ConfirmDialog.svelte';
+ import { ConfirmationModal } from '@manacore/shared-ui';
import { CaretRight } from '@manacore/shared-icons';
const allClients = getContext<{ value: Client[] }>('clients');
@@ -348,10 +348,10 @@
{/if}
- (deleteConfirmId = null)}
+ onClose={() => (deleteConfirmId = null)}
/>
diff --git a/apps/times/apps/web/src/routes/(app)/projects/+page.svelte b/apps/times/apps/web/src/routes/(app)/projects/+page.svelte
index 20e53ee47..1934f049e 100644
--- a/apps/times/apps/web/src/routes/(app)/projects/+page.svelte
+++ b/apps/times/apps/web/src/routes/(app)/projects/+page.svelte
@@ -5,7 +5,7 @@
import { getTotalDuration, formatDurationCompact } from '$lib/data/queries';
import type { Project, Client, TimeEntry } from '@times/shared';
import { PROJECT_COLORS } from '@times/shared/constants';
- import ConfirmDialog from '$lib/components/ConfirmDialog.svelte';
+ import { ConfirmationModal } from '@manacore/shared-ui';
import { CaretRight } from '@manacore/shared-icons';
const allProjects = getContext<{ value: Project[] }>('projects');
@@ -357,10 +357,10 @@
{/if}
- (deleteConfirmId = null)}
+ onClose={() => (deleteConfirmId = null)}
/>
diff --git a/apps/todo/apps/web/src/lib/components/AppSlider.svelte b/apps/todo/apps/web/src/lib/components/AppSlider.svelte
index ac8bb846d..fa235be31 100644
--- a/apps/todo/apps/web/src/lib/components/AppSlider.svelte
+++ b/apps/todo/apps/web/src/lib/components/AppSlider.svelte
@@ -1,9 +1,9 @@
-
-
-
- {#if isOpen}
-
- {#each supportedLocales as lang}
-
- {/each}
-
- {/if}
-
-
-{#if isOpen}
-
-{/if}
+
diff --git a/apps/context/apps/web/src/routes/(app)/spaces/[id]/+page.svelte b/apps/context/apps/web/src/routes/(app)/spaces/[id]/+page.svelte
index 5449b0f55..40c8ec82f 100644
--- a/apps/context/apps/web/src/routes/(app)/spaces/[id]/+page.svelte
+++ b/apps/context/apps/web/src/routes/(app)/spaces/[id]/+page.svelte
@@ -21,7 +21,7 @@
findSpaceById,
} from '$lib/data/queries';
import DocumentCard from '$lib/components/DocumentCard.svelte';
- import ConfirmDialog from '$lib/components/ConfirmDialog.svelte';
+ import { ConfirmationModal } from '@manacore/shared-ui';
import BatchCreateModal from '$lib/components/BatchCreateModal.svelte';
import type { Space, DocumentType } from '$lib/types';
@@ -270,14 +270,13 @@
{/if}
- (deleteTarget = null)}
+ onClose={() => (deleteTarget = null)}
/>
import { AppSlider } from '@manacore/shared-ui';
import type { AppItem } from '@manacore/shared-ui';
- import { MANA_APPS, APP_STATUS_LABELS, APP_SLIDER_LABELS } from '@manacore/shared-branding';
+ import { getActiveManaApps, APP_STATUS_LABELS, APP_SLIDER_LABELS } from '@manacore/shared-branding';
- // Convert MANA_APPS to AppItem format (English)
- const apps: AppItem[] = MANA_APPS.map((app) => ({
+ // Convert active apps to AppItem format (English)
+ const apps: AppItem[] = getActiveManaApps().map((app) => ({
name: app.name,
description: app.description.en,
longDescription: app.longDescription.en,